Documentation
¶
Index ¶
- Constants
- func CompareCurrencyPairFormats(pair1 config.CurrencyPairFormatConfig, pair2 *config.CurrencyPairFormatConfig) bool
- func FilterOrdersByCurrencies(orders *[]OrderDetail, currencies []currency.Pair)
- func FilterOrdersBySide(orders *[]OrderDetail, orderSide OrderSide)
- func FilterOrdersByTickRange(orders *[]OrderDetail, startTicks, endTicks time.Time)
- func FilterOrdersByType(orders *[]OrderDetail, orderType OrderType)
- func FormatCurrency(p currency.Pair) currency.Pair
- func FormatExchangeCurrency(exchName string, p currency.Pair) currency.Pair
- func GetAndFormatExchangeCurrencies(exchName string, pairs []currency.Pair) (string, error)
- func GetExchangeAssetTypes(exchName string) ([]string, error)
- func GetExchangeFormatCurrencySeperator(exchName string) bool
- func SortOrdersByCurrency(orders *[]OrderDetail, reverse bool)
- func SortOrdersByDate(orders *[]OrderDetail, reverse bool)
- func SortOrdersByPrice(orders *[]OrderDetail, reverse bool)
- func SortOrdersBySide(orders *[]OrderDetail, reverse bool)
- func SortOrdersByType(orders *[]OrderDetail, reverse bool)
- type Account
- type AccountCurrencyInfo
- type AccountInfo
- type Base
- func (e *Base) FormatWithdrawPermissions() string
- func (e *Base) GetAPIURL() string
- func (e *Base) GetAPIURLDefault() string
- func (e *Base) GetAPIURLSecondaryDefault() string
- func (e *Base) GetAssetTypes() []string
- func (e *Base) GetAuthenticatedAPISupport(endpoint uint8) bool
- func (e *Base) GetAvailableCurrencies() currency.Pairs
- func (e *Base) GetClientBankAccounts(exchangeName, withdrawalCurrency string) (config.BankAccount, error)
- func (e *Base) GetEnabledCurrencies() currency.Pairs
- func (e *Base) GetExchangeBankAccounts(exchangeName, depositCurrency string) (config.BankAccount, error)
- func (e *Base) GetHTTPClient() *http.Client
- func (e *Base) GetHTTPClientUserAgent() string
- func (e *Base) GetLastPairsUpdateTime() int64
- func (e *Base) GetName() string
- func (e *Base) GetSecondaryAPIURL() string
- func (e *Base) GetWithdrawPermissions() uint32
- func (e *Base) IsEnabled() bool
- func (e *Base) SetAPIKeys(apiKey, apiSecret, clientID string, b64Decode bool)
- func (e *Base) SetAPIURL(ec *config.ExchangeConfig) error
- func (e *Base) SetAssetTypes() error
- func (e *Base) SetAutoPairDefaults() error
- func (e *Base) SetClientProxyAddress(addr string) error
- func (e *Base) SetCurrencies(pairs []currency.Pair, enabledPairs bool) error
- func (e *Base) SetCurrencyPairFormat() error
- func (e *Base) SetEnabled(enabled bool)
- func (e *Base) SetHTTPClient(h *http.Client)
- func (e *Base) SetHTTPClientTimeout(t time.Duration)
- func (e *Base) SetHTTPClientUserAgent(ua string)
- func (e *Base) SupportsAutoPairUpdates() bool
- func (e *Base) SupportsCurrency(p currency.Pair, enabledPairs bool) bool
- func (e *Base) SupportsRESTTickerBatchUpdates() bool
- func (e *Base) SupportsWithdrawPermissions(permissions uint32) bool
- func (e *Base) UpdateCurrencies(exchangeProducts currency.Pairs, enabled, force bool) error
- type ByCurrency
- type ByDate
- type ByOrderSide
- type ByOrderType
- type ByPrice
- type CancelAllOrdersResponse
- type FeeBuilder
- type FeeType
- type Format
- type Formatting
- type FundHistory
- type GetOrdersRequest
- type IBotExchange
- type InternationalBankTransactionType
- type ModifyOrder
- type ModifyOrderResponse
- type OrderCancellation
- type OrderDetail
- type OrderSide
- type OrderStatus
- type OrderType
- type SubmitOrderResponse
- type TradeHistory
- type WithdrawRequest
Constants ¶
const ( // WarningAuthenticatedRequestWithoutCredentialsSet error message for authenticated request without credentials set WarningAuthenticatedRequestWithoutCredentialsSet = "exchange %s authenticated HTTP request called but not supported due to unset/default API keys" // ErrExchangeNotFound is a stand for an error message ErrExchangeNotFound = "exchange not found in dataset" // DefaultHTTPTimeout is the default HTTP/HTTPS Timeout for exchange requests DefaultHTTPTimeout = time.Second * 15 // DefaultWebsocketResponseCheckTimeout is the default delay in checking for an expected websocket response DefaultWebsocketResponseCheckTimeout = time.Millisecond * 30 // DefaultWebsocketResponseMaxLimit is the default max wait for an expected websocket response before a timeout DefaultWebsocketResponseMaxLimit = time.Second * 7 // DefaultWebsocketOrderbookBufferLimit is the maximum number of orderbook updates that get stored before being applied DefaultWebsocketOrderbookBufferLimit = 5 )
const ( // No withdraw NoAPIWithdrawalMethods uint32 = 0 NoAPIWithdrawalMethodsText string = "NONE, WEBSITE ONLY" AutoWithdrawCrypto uint32 = (1 << 0) AutoWithdrawCryptoWithAPIPermission uint32 = (1 << 1) AutoWithdrawCryptoWithSetup uint32 = (1 << 2) AutoWithdrawCryptoText string = "AUTO WITHDRAW CRYPTO" AutoWithdrawCryptoWithAPIPermissionText string = "AUTO WITHDRAW CRYPTO WITH API PERMISSION" AutoWithdrawCryptoWithSetupText string = "AUTO WITHDRAW CRYPTO WITH SETUP" WithdrawCryptoWith2FA uint32 = (1 << 3) WithdrawCryptoWithSMS uint32 = (1 << 4) WithdrawCryptoWithEmail uint32 = (1 << 5) WithdrawCryptoWithWebsiteApproval uint32 = (1 << 6) WithdrawCryptoWithAPIPermission uint32 = (1 << 7) WithdrawCryptoWith2FAText string = "WITHDRAW CRYPTO WITH 2FA" WithdrawCryptoWithSMSText string = "WITHDRAW CRYPTO WITH SMS" WithdrawCryptoWithEmailText string = "WITHDRAW CRYPTO WITH EMAIL" WithdrawCryptoWithWebsiteApprovalText string = "WITHDRAW CRYPTO WITH WEBSITE APPROVAL" WithdrawCryptoWithAPIPermissionText string = "WITHDRAW CRYPTO WITH API PERMISSION" AutoWithdrawFiat uint32 = (1 << 8) AutoWithdrawFiatWithAPIPermission uint32 = (1 << 9) AutoWithdrawFiatWithSetup uint32 = (1 << 10) AutoWithdrawFiatText string = "AUTO WITHDRAW FIAT" AutoWithdrawFiatWithAPIPermissionText string = "AUTO WITHDRAW FIAT WITH API PERMISSION" AutoWithdrawFiatWithSetupText string = "AUTO WITHDRAW FIAT WITH SETUP" WithdrawFiatWith2FA uint32 = (1 << 11) WithdrawFiatWithSMS uint32 = (1 << 12) WithdrawFiatWithEmail uint32 = (1 << 13) WithdrawFiatWithWebsiteApproval uint32 = (1 << 14) WithdrawFiatWithAPIPermission uint32 = (1 << 15) WithdrawFiatWith2FAText string = "WITHDRAW FIAT WITH 2FA" WithdrawFiatWithSMSText string = "WITHDRAW FIAT WITH SMS" WithdrawFiatWithEmailText string = "WITHDRAW FIAT WITH EMAIL" WithdrawFiatWithWebsiteApprovalText string = "WITHDRAW FIAT WITH WEBSITE APPROVAL" WithdrawFiatWithAPIPermissionText string = "WITHDRAW FIAT WITH API PERMISSION" WithdrawCryptoViaWebsiteOnly uint32 = (1 << 16) WithdrawFiatViaWebsiteOnly uint32 = (1 << 17) WithdrawCryptoViaWebsiteOnlyText string = "WITHDRAW CRYPTO VIA WEBSITE ONLY" WithdrawFiatViaWebsiteOnlyText string = "WITHDRAW FIAT VIA WEBSITE ONLY" NoFiatWithdrawals uint32 = (1 << 18) NoFiatWithdrawalsText string = "NO FIAT WITHDRAWAL" UnknownWithdrawalTypeText string = "UNKNOWN" RestAuthentication uint8 = 0 WebsocketAuthentication uint8 = 1 )
Definitions for each type of withdrawal method for a given exchange
Variables ¶
This section is empty.
Functions ¶
func CompareCurrencyPairFormats ¶
func CompareCurrencyPairFormats(pair1 config.CurrencyPairFormatConfig, pair2 *config.CurrencyPairFormatConfig) bool
CompareCurrencyPairFormats checks and returns whether or not the two supplied config currency pairs match
func FilterOrdersByCurrencies ¶
func FilterOrdersByCurrencies(orders *[]OrderDetail, currencies []currency.Pair)
FilterOrdersByCurrencies removes any OrderDetails that do not match the provided currency list It is forgiving in that the provided currencies can match quote or base currencies
func FilterOrdersBySide ¶
func FilterOrdersBySide(orders *[]OrderDetail, orderSide OrderSide)
FilterOrdersBySide removes any OrderDetails that don't match the orderStatus provided
func FilterOrdersByTickRange ¶
func FilterOrdersByTickRange(orders *[]OrderDetail, startTicks, endTicks time.Time)
FilterOrdersByTickRange removes any OrderDetails outside of the tick range
func FilterOrdersByType ¶
func FilterOrdersByType(orders *[]OrderDetail, orderType OrderType)
FilterOrdersByType removes any OrderDetails that don't match the orderType provided
func FormatCurrency ¶
FormatCurrency is a method that formats and returns a currency pair based on the user currency display preferences
func FormatExchangeCurrency ¶
FormatExchangeCurrency is a method that formats and returns a currency pair based on the exchange currency format
func GetAndFormatExchangeCurrencies ¶
GetAndFormatExchangeCurrencies returns a pair.CurrencyItem string containing the exchanges formatted currency pairs
func GetExchangeAssetTypes ¶
GetExchangeAssetTypes returns the asset types the exchange supports (SPOT, binary, futures)
func GetExchangeFormatCurrencySeperator ¶
GetExchangeFormatCurrencySeperator returns whether or not a specific exchange contains a separator used for API requests
func SortOrdersByCurrency ¶
func SortOrdersByCurrency(orders *[]OrderDetail, reverse bool)
SortOrdersByCurrency the caller function to sort orders
func SortOrdersByDate ¶
func SortOrdersByDate(orders *[]OrderDetail, reverse bool)
SortOrdersByDate the caller function to sort orders
func SortOrdersByPrice ¶
func SortOrdersByPrice(orders *[]OrderDetail, reverse bool)
SortOrdersByPrice the caller function to sort orders
func SortOrdersBySide ¶
func SortOrdersBySide(orders *[]OrderDetail, reverse bool)
SortOrdersBySide the caller function to sort orders
func SortOrdersByType ¶
func SortOrdersByType(orders *[]OrderDetail, reverse bool)
SortOrdersByType the caller function to sort orders
Types ¶
type Account ¶
type Account struct {
ID string
Currencies []AccountCurrencyInfo
}
Account defines a singular account type with asocciated currencies
type AccountCurrencyInfo ¶
AccountCurrencyInfo is a sub type to store currency name and value
type AccountInfo ¶
AccountInfo is a Generic type to hold each exchange's holdings in all enabled currencies
type Base ¶
type Base struct {
Name string
Enabled bool
Verbose bool
RESTPollingDelay time.Duration
WebsocketResponseCheckTimeout time.Duration
WebsocketResponseMaxLimit time.Duration
WebsocketOrderbookBufferLimit int64
AuthenticatedAPISupport bool
AuthenticatedWebsocketAPISupport bool
APIWithdrawPermissions uint32
APIAuthPEMKeySupport bool
APISecret, APIKey, APIAuthPEMKey, ClientID string
TakerFee, MakerFee, Fee float64
BaseCurrencies currency.Currencies
AvailablePairs currency.Pairs
EnabledPairs currency.Pairs
AssetTypes []string
PairsLastUpdated int64
SupportsAutoPairUpdating bool
SupportsRESTTickerBatching bool
HTTPTimeout time.Duration
HTTPUserAgent string
HTTPDebugging bool
HTTPRecording bool
WebsocketURL string
APIUrl string
APIUrlDefault string
APIUrlSecondary string
APIUrlSecondaryDefault string
RequestCurrencyPairFormat config.CurrencyPairFormatConfig
ConfigCurrencyPairFormat config.CurrencyPairFormatConfig
Websocket *wshandler.Websocket
*request.Requester
}
Base stores the individual exchange information
func (*Base) FormatWithdrawPermissions ¶
FormatWithdrawPermissions will return each of the exchange's compatible withdrawal methods in readable form
func (*Base) GetAPIURLDefault ¶
GetAPIURLDefault returns exchange default URL
func (*Base) GetAPIURLSecondaryDefault ¶
GetAPIURLSecondaryDefault returns exchange default secondary URL
func (*Base) GetAssetTypes ¶
GetAssetTypes returns the available asset types for an individual exchange
func (*Base) GetAuthenticatedAPISupport ¶
GetAuthenticatedAPISupport returns whether the exchange supports authenticated API requests
func (*Base) GetAvailableCurrencies ¶
GetAvailableCurrencies is a method that returns the available currency pairs of the exchange base
func (*Base) GetClientBankAccounts ¶
func (e *Base) GetClientBankAccounts(exchangeName, withdrawalCurrency string) (config.BankAccount, error)
GetClientBankAccounts returns banking details associated with a client for withdrawal purposes
func (*Base) GetEnabledCurrencies ¶
GetEnabledCurrencies is a method that returns the enabled currency pairs of the exchange base
func (*Base) GetExchangeBankAccounts ¶
func (e *Base) GetExchangeBankAccounts(exchangeName, depositCurrency string) (config.BankAccount, error)
GetExchangeBankAccounts returns banking details associated with an exchange for funding purposes
func (*Base) GetHTTPClient ¶
GetHTTPClient gets the exchanges HTTP client
func (*Base) GetHTTPClientUserAgent ¶
GetHTTPClientUserAgent gets the exchanges HTTP user agent
func (*Base) GetLastPairsUpdateTime ¶
GetLastPairsUpdateTime returns the unix timestamp of when the exchanges currency pairs were last updated
func (*Base) GetSecondaryAPIURL ¶
GetSecondaryAPIURL returns the set Secondary API URL
func (*Base) GetWithdrawPermissions ¶
GetWithdrawPermissions passes through the exchange's withdraw permissions
func (*Base) SetAPIKeys ¶
SetAPIKeys is a method that sets the current API keys for the exchange
func (*Base) SetAPIURL ¶
func (e *Base) SetAPIURL(ec *config.ExchangeConfig) error
SetAPIURL sets configuration API URL for an exchange
func (*Base) SetAssetTypes ¶
SetAssetTypes checks the exchange asset types (whether it supports SPOT, Binary or Futures) and sets it to a default setting if it doesn't exist
func (*Base) SetAutoPairDefaults ¶
SetAutoPairDefaults sets the default values for whether or not the exchange supports auto pair updating or not
func (*Base) SetClientProxyAddress ¶
SetClientProxyAddress sets a proxy address for REST and websocket requests
func (*Base) SetCurrencies ¶
SetCurrencies sets the exchange currency pairs for either enabledPairs or availablePairs
func (*Base) SetCurrencyPairFormat ¶
SetCurrencyPairFormat checks the exchange request and config currency pair formats and sets it to a default setting if it doesn't exist
func (*Base) SetEnabled ¶
SetEnabled is a method that sets if the exchange is enabled
func (*Base) SetHTTPClient ¶
SetHTTPClient sets exchanges HTTP client
func (*Base) SetHTTPClientTimeout ¶
SetHTTPClientTimeout sets the timeout value for the exchanges HTTP Client
func (*Base) SetHTTPClientUserAgent ¶
SetHTTPClientUserAgent sets the exchanges HTTP user agent
func (*Base) SupportsAutoPairUpdates ¶
SupportsAutoPairUpdates returns whether or not the exchange supports auto currency pair updating
func (*Base) SupportsCurrency ¶
SupportsCurrency returns true or not whether a currency pair exists in the exchange available currencies or not
func (*Base) SupportsRESTTickerBatchUpdates ¶
SupportsRESTTickerBatchUpdates returns whether or not the exhange supports REST batch ticker fetching
func (*Base) SupportsWithdrawPermissions ¶
SupportsWithdrawPermissions compares the supplied permissions with the exchange's to verify they're supported
type ByCurrency ¶
type ByCurrency []OrderDetail
ByCurrency used for sorting orders by order currency
func (ByCurrency) Len ¶
func (b ByCurrency) Len() int
func (ByCurrency) Less ¶
func (b ByCurrency) Less(i, j int) bool
func (ByCurrency) Swap ¶
func (b ByCurrency) Swap(i, j int)
type ByOrderSide ¶
type ByOrderSide []OrderDetail
ByOrderSide used for sorting orders by order side (buy sell)
func (ByOrderSide) Len ¶
func (b ByOrderSide) Len() int
func (ByOrderSide) Less ¶
func (b ByOrderSide) Less(i, j int) bool
func (ByOrderSide) Swap ¶
func (b ByOrderSide) Swap(i, j int)
type ByOrderType ¶
type ByOrderType []OrderDetail
ByOrderType used for sorting orders by order type
func (ByOrderType) Len ¶
func (b ByOrderType) Len() int
func (ByOrderType) Less ¶
func (b ByOrderType) Less(i, j int) bool
func (ByOrderType) Swap ¶
func (b ByOrderType) Swap(i, j int)
type CancelAllOrdersResponse ¶
CancelAllOrdersResponse returns the status from attempting to cancel all orders on an exchange
type FeeBuilder ¶
type FeeBuilder struct {
IsMaker bool
PurchasePrice float64
Amount float64
FeeType FeeType
FiatCurrency currency.Code
BankTransactionType InternationalBankTransactionType
Pair currency.Pair
}
FeeBuilder is the type which holds all parameters required to calculate a fee for an exchange
type FundHistory ¶
type FundHistory struct {
ExchangeName string
Status string
TransferID string
Description string
Timestamp time.Time
Currency string
Amount float64
Fee float64
TransferType string
CryptoToAddress string
CryptoFromAddress string
CryptoTxID string
BankTo string
BankFrom string
}
FundHistory holds exchange funding history data
type GetOrdersRequest ¶
type GetOrdersRequest struct {
OrderType OrderType
OrderSide OrderSide
StartTicks time.Time
EndTicks time.Time
// Currencies Empty array = all currencies. Some endpoints only support singular currency enquiries
Currencies []currency.Pair
}
GetOrdersRequest used for GetOrderHistory and GetOpenOrders wrapper functions
type IBotExchange ¶
type IBotExchange interface {
Setup(exch *config.ExchangeConfig)
Start(wg *sync.WaitGroup)
SetDefaults()
GetName() string
IsEnabled() bool
SetEnabled(bool)
GetTickerPrice(currency currency.Pair, assetType string) (ticker.Price, error)
UpdateTicker(currency currency.Pair, assetType string) (ticker.Price, error)
GetOrderbookEx(currency currency.Pair, assetType string) (orderbook.Base, error)
UpdateOrderbook(currency currency.Pair, assetType string) (orderbook.Base, error)
GetEnabledCurrencies() currency.Pairs
GetAvailableCurrencies() currency.Pairs
GetAssetTypes() []string
GetAccountInfo() (AccountInfo, error)
GetAuthenticatedAPISupport(endpoint uint8) bool
SetCurrencies(pairs []currency.Pair, enabledPairs bool) error
GetExchangeHistory(p currency.Pair, assetType string) ([]TradeHistory, error)
SupportsAutoPairUpdates() bool
GetLastPairsUpdateTime() int64
SupportsRESTTickerBatchUpdates() bool
GetFeeByType(feeBuilder *FeeBuilder) (float64, error)
GetWithdrawPermissions() uint32
FormatWithdrawPermissions() string
SupportsWithdrawPermissions(permissions uint32) bool
GetFundingHistory() ([]FundHistory, error)
SubmitOrder(p currency.Pair, side OrderSide, orderType OrderType, amount, price float64, clientID string) (SubmitOrderResponse, error)
ModifyOrder(action *ModifyOrder) (string, error)
CancelOrder(order *OrderCancellation) error
CancelAllOrders(orders *OrderCancellation) (CancelAllOrdersResponse, error)
GetOrderInfo(orderID string) (OrderDetail, error)
GetDepositAddress(cryptocurrency currency.Code, accountID string) (string, error)
GetOrderHistory(getOrdersRequest *GetOrdersRequest) ([]OrderDetail, error)
GetActiveOrders(getOrdersRequest *GetOrdersRequest) ([]OrderDetail, error)
WithdrawCryptocurrencyFunds(withdrawRequest *WithdrawRequest) (string, error)
WithdrawFiatFunds(withdrawRequest *WithdrawRequest) (string, error)
WithdrawFiatFundsToInternationalBank(withdrawRequest *WithdrawRequest) (string, error)
GetWebsocket() (*wshandler.Websocket, error)
SubscribeToWebsocketChannels(channels []wshandler.WebsocketChannelSubscription) error
UnsubscribeToWebsocketChannels(channels []wshandler.WebsocketChannelSubscription) error
AuthenticateWebsocket() error
GetSubscriptions() ([]wshandler.WebsocketChannelSubscription, error)
}
IBotExchange enforces standard functions for all exchanges supported in GoCryptoTrader
type InternationalBankTransactionType ¶
type InternationalBankTransactionType uint8
InternationalBankTransactionType custom type for calculating fees based on fiat transaction types
const ( WireTransfer InternationalBankTransactionType = iota PerfectMoney Neteller AdvCash Payeer Skrill Simplex SEPA Swift RapidTransfer MisterTangoSEPA Qiwi VisaMastercard WebMoney Capitalist WesternUnion MoneyGram Contact )
Const declarations for international transaction types
type ModifyOrder ¶
type ModifyOrder struct {
OrderID string
OrderType
OrderSide
Price float64
Amount float64
LimitPriceUpper float64
LimitPriceLower float64
CurrencyPair currency.Pair
ImmediateOrCancel bool
HiddenOrder bool
FillOrKill bool
PostOnly bool
}
ModifyOrder is a an order modifyer
type ModifyOrderResponse ¶
type ModifyOrderResponse struct {
OrderID string
}
ModifyOrderResponse is an order modifying return type
type OrderCancellation ¶
type OrderCancellation struct {
AccountID string
OrderID string
WalletAddress string
Side OrderSide
CurrencyPair currency.Pair
}
OrderCancellation type required when requesting to cancel an order
type OrderDetail ¶
type OrderDetail struct {
Exchange string
AccountID string
ID string
CurrencyPair currency.Pair
OrderSide OrderSide
OrderType OrderType
OrderDate time.Time
Status string
Price float64
Amount float64
ExecutedAmount float64
RemainingAmount float64
Fee float64
Trades []TradeHistory
}
OrderDetail holds order detail data
type OrderSide ¶
type OrderSide string
OrderSide enforces a standard for OrderSides across the code base
type OrderStatus ¶
type OrderStatus string
OrderStatus defines order status types
const ( AnyOrderStatus OrderStatus = "ANY" NewOrderStatus OrderStatus = "NEW" ActiveOrderStatus OrderStatus = "ACTIVE" PartiallyFilledOrderStatus OrderStatus = "PARTIALLY_FILLED" FilledOrderStatus OrderStatus = "FILLED" CancelledOrderStatus OrderStatus = "CANCELED" PendingCancelOrderStatus OrderStatus = "PENDING_CANCEL" RejectedOrderStatus OrderStatus = "REJECTED" ExpiredOrderStatus OrderStatus = "EXPIRED" HiddenOrderStatus OrderStatus = "HIDDEN" UnknownOrderStatus OrderStatus = "UNKNOWN" )
All OrderStatus types
type OrderType ¶
type OrderType string
OrderType enforces a standard for Ordertypes across the code base
const ( AnyOrderType OrderType = "ANY" LimitOrderType OrderType = "LIMIT" MarketOrderType OrderType = "MARKET" ImmediateOrCancelOrderType OrderType = "IMMEDIATE_OR_CANCEL" StopOrderType OrderType = "STOP" TrailingStopOrderType OrderType = "TRAILINGSTOP" UnknownOrderType OrderType = "UNKNOWN" )
OrderType ...types
type SubmitOrderResponse ¶
SubmitOrderResponse is what is returned after submitting an order to an exchange
type TradeHistory ¶
type TradeHistory struct {
Timestamp time.Time
TID int64
Price float64
Amount float64
Exchange string
Type string
Fee float64
Description string
}
TradeHistory holds exchange history data
type WithdrawRequest ¶
type WithdrawRequest struct {
// General withdraw information
Description string
OneTimePassword int64
AccountID string
PIN int64
TradePassword string
Amount float64
Currency currency.Code
// Crypto related information
Address string
AddressTag string
FeeAmount float64
// FIAT related information
BankAccountName string
BankAccountNumber float64
BankName string
BankAddress string
BankCity string
BankCountry string
BankPostalCode string
SwiftCode string
IBAN string
BankCode float64
IsExpressWire bool
// Intermediary bank information
RequiresIntermediaryBank bool
IntermediaryBankAccountNumber float64
IntermediaryBankName string
IntermediaryBankAddress string
IntermediaryBankCity string
IntermediaryBankCountry string
IntermediaryBankPostalCode string
IntermediarySwiftCode string
IntermediaryBankCode float64
IntermediaryIBAN string
WireCurrency string
}
WithdrawRequest used for wrapper crypto and FIAT withdraw methods
Directories
¶
| Path | Synopsis |
|---|---|
|
Package gemini exchange documentation can be found at https://docs.sandbox.gemini.com
|
Package gemini exchange documentation can be found at https://docs.sandbox.gemini.com |
|
websocket
|
|